# Top Navigation

## left
* [📚 Docs Home](index.md)
* [🚀 Quick Start](quick-setup.md)

## right
* [GitHub](https://github.com/yourusername/markdown-docs-server)
* [Docker Hub](https://hub.docker.com/r/yourusername/markdown-docs-server)
* {{search:icon=lucide-search,mode=button,placeholder=Search...}}

<!-- Re{{search}} the {{search}} tag: see Navigation docs for mode, icon, and more. -->
